LEDMaterial

Struct LEDMaterial 

pub struct LEDMaterial { /* private fields */ }
Static led material.

It lets you add emission to material or make it like transparent like glass.

Examples:

For the effect from the examples:

LEDMaterial::default();

You can specify your own color and emission intensity of cource:

LEDMaterial::new(Color::WHITE).with_emission(3.0);

Implementations

Source

impl LEDMaterial

pub fn new(color: Color) -> Self

pub fn with_emission(self, intensity: f32) -> Self